; Ŀ
;  Procedure name: TabLock(TabLockSpec)                                      
;                                                                            
;  Purpose: TabLock is procedure to apply table one or more locks in a multi-
;  user environment.   If the lock(s) succeed the first time, True is        
;  returned.  If the lock(s) fail, a message is displayed to the user        
;  telling them that the lock is being retried.  During retry, the user can  
;  press Esc to cancel the lock attempt, at which time False is returned.    
;  As long as the lock retry period is short enough, this procedure will     
;  continue to retry the lock attempt as long as the user wants.  The short  
;  retry period is essential so that an Esc press is tested for at           
;  reasonably short intervals.  If the retry period is too long, the user may
;  conclude that the system has locked, and may be tempted to re-boot.       
;  It is essential that the tablockspec passed this procedure make use of    
;  backslashes before each quote that appears surrounding alphanumeric       
;  constants.                                                                
;                                                                            
;    This script is part of a sample application described in the          
;    October 1993 issue of Paradox Information.  This script was written   
;    by Cary Jensen of Data Works of Houston.                              
;                                                                            
;    This script is for demonstration purposes only.  No representation      
;    is made concerning the appropriateness of this script for any other     
;    purpose.  If you use this script you agree to hold its author and       
;    Data Works of Houston free from any claim arising out of the use or     
;    misuse of this script.                                                  
; ͵
;                              Cary Jensen                                   
;                          Data Works of Houston                             
;                             CIS 76307,1533                                 
;                             (713) 359-3311                                 
; ͵
; 
PROC TabLock(TabLockSpec)
PRIVATE NameOfUser, zz

  ;Retry period should be defined in the startup (Go) or Main menu scripts
  ;About 2 seconds should be fine

  EXECUTE "LOCK "+TabLockSpec

  IF NOT Retval
    THEN
      ;Retval is False the specified locks fail.  Display a message to the user.
      BEEP
      MESSAGE "This selection unavailable.  Trying to access...  Press Esc to cancel."
      ;Flush the keyboard buffer
      WHILE CHARWAITING()
        zz = GETCHAR()
      ENDWHILE
      ;Repeat the lock attempt until the lock is applied or user presses Esc.
      WHILE True
        ;Try the lock again
        EXECUTE "LOCK "+TabLockSpec
        IF NOT Retval
          THEN
            ;It failed.  Repeat the message and test for any keypresses
            MESSAGE "This selection unavailable.  Trying to access...  Press Esc to cancel."
            WHILE CHARWAITING()
              ;There was a keypress.  Was it an escape?
              z = GETCHAR()
              IF z = 27
                THEN
                  ;User pressed Esc.  Return the value False
                  RETURN False
              ENDIF
            ENDWHILE
          ELSE
            ;The lock was successfully applied on retry.  Return the value True
            RETURN True
        ENDIF
      ENDWHILE
    ELSE
      ;The first attempt to apply the specified lock works.  Return True
      RETURN True
  ENDIF

ENDPROC ; ---TabLock(TabLockSpec)
WRITELIB "Paradox" TabLock
RELEASE PROCS TabLock
